@@ -8,30 +8,30 @@ def parse(sentence_list):
         sentence = input_list.pop()
 
         if (type(sentence) is Atomic) or (type(sentence) is Invert):
-            parsed_list.add(sentence)
+            parsed_list.append(sentence)
 
         elif type(sentence) is Conjunction:
-            input_list.add(sentence.lchild)
-            input_list.add(sentence.rchild)
+            input_list.append(sentence.lchild)
+            input_list.append(sentence.rchild)
 
         elif type(sentence) is Disjunction:
             if (~sentence.lchild).validate(input_list + parsed_list):
-                input_list.add(sentence.rchild)
+                input_list.append(sentence.rchild)
             elif (~sentence.rchild).validate(input_list + parsed_list):
-                input_list.add(sentence.lchild)
+                input_list.append(sentence.lchild)
 
         elif type(sentence) is Implication:
             if sentence.lchild.validate(input_list + parsed_list):
-                input_list.add(sentence.rchild)
+                input_list.append(sentence.rchild)
 
         elif type(sentence) is Equality:
             if sentence.lchild.validate(input_list + parsed_list):
-                input_list.add(sentence.rchild)
+                input_list.append(sentence.rchild)
             elif sentence.rchild.validate(input_list + parsed_list):
-                input_list.add(sentence.lchild)
+                input_list.append(sentence.lchild)
             elif (~sentence.lchild).validate(input_list + parsed_list):
-                input_list.add(~sentence.rchild)
+                input_list.append(~sentence.rchild)
             elif (~sentence.rchild).validate(input_list + parsed_list):
-                input_list.add(~sentence.lchild)
+                input_list.append(~sentence.lchild)
 
     return set(parsed_list)
\ No newline at end of file
